CapacitanceRate

Struct CapacitanceRate 

pub struct CapacitanceRate(/* private fields */);
Capacitance rate (m_dot * c_p) of a working fluid in a heat exchanger.

The value must be strictly positive.

Implementations

Source

impl CapacitanceRate

pub fn new<U>(value: f64) -> ConstraintResult<Self>
where U: Unit + Conversion<f64, T = f64>,

Create a CapacitanceRate from a scalar value.

Errors

Returns Err if the value is not strictly positive.

pub fn from_quantity(quantity: ThermalConductance) -> ConstraintResult<Self>

Create a CapacitanceRate from a quantity with thermal-conductance units.

Errors

Returns Err if the quantity is not strictly positive.

pub fn from_mass_rate_and_specific_heat( mass_rate: MassRate, specific_heat: SpecificHeatCapacity, ) -> ConstraintResult<Self>

Create a CapacitanceRate from a mass rate and specific heat capacity.

Errors

Returns Err if either operand is not strictly positive.

Methods from Deref<Target = ThermalConductance>

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub const HALF_TURN: Quantity<dyn Dimension<T = Z0, Kind = dyn AngleKind, M = Z0, J = Z0, L = Z0, N = Z0, I = Z0, Th = Z0>, dyn Units<f32, amount_of_substance = mole, mass = kilogram, time = second, electric_current = ampere, length = meter, thermodynamic_temperature = kelvin, luminous_intensity = candela>, f32>

pub const FULL_TURN: Quantity<dyn Dimension<T = Z0, Kind = dyn AngleKind, M = Z0, J = Z0, L = Z0, N = Z0, I = Z0, Th = Z0>, dyn Units<f32, amount_of_substance = mole, mass = kilogram, time = second, electric_current = ampere, length = meter, thermodynamic_temperature = kelvin, luminous_intensity = candela>, f32>

pub const HALF_TURN: Quantity<dyn Dimension<T = Z0, Kind = dyn AngleKind, M = Z0, J = Z0, L = Z0, N = Z0, I = Z0, Th = Z0>, dyn Units<f64, amount_of_substance = mole, mass = kilogram, time = second, electric_current = ampere, length = meter, thermodynamic_temperature = kelvin, luminous_intensity = candela>, f64>

pub const FULL_TURN: Quantity<dyn Dimension<T = Z0, Kind = dyn AngleKind, M = Z0, J = Z0, L = Z0, N = Z0, I = Z0, Th = Z0>, dyn Units<f64, amount_of_substance = mole, mass = kilogram, time = second, electric_current = ampere, length = meter, thermodynamic_temperature = kelvin, luminous_intensity = candela>, f64>

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub const SPHERE: Quantity<dyn Dimension<T = Z0, Kind = dyn SolidAngleKind, M = Z0, J = Z0, L = Z0, N = Z0, I = Z0, Th = Z0>, dyn Units<f32, amount_of_substance = mole, mass = kilogram, time = second, electric_current = ampere, length = meter, thermodynamic_temperature = kelvin, luminous_intensity = candela>, f32>

pub const SPHERE: Quantity<dyn Dimension<T = Z0, Kind = dyn SolidAngleKind, M = Z0, J = Z0, L = Z0, N = Z0, I = Z0, Th = Z0>, dyn Units<f64, amount_of_substance = mole, mass = kilogram, time = second, electric_current = ampere, length = meter, thermodynamic_temperature = kelvin, luminous_intensity = candela>, f64>

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.