Effectiveness

Struct Effectiveness 

pub struct Effectiveness(/* private fields */);
The effectiveness of a heat exchanger.

The effectiveness is the ratio of the actual amount of heat transferred to the maximum possible amount of heat transferred in the heat exchanger.

The effectiveness must be in the interval [0, 1].

Implementations

Source

impl Effectiveness

pub fn new(value: f64) -> ConstraintResult<Self>

Create an Effectiveness from a scalar value.

Errors

Returns Err if the value lies outside the interval [0, 1].

pub fn from_quantity(quantity: Ratio) -> ConstraintResult<Self>

Create an Effectiveness from a ratio quantity.

Errors

Returns Err if the quantity lies outside the interval [0, 1].

Methods from Deref<Target = Ratio>

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub const HALF_TURN: Quantity<dyn Dimension<Kind = dyn AngleKind, N = Z0, J = Z0, M = Z0, L = Z0, I = Z0, T = Z0, Th = Z0>, dyn Units<f32, mass = kilogram, electric_current = ampere, amount_of_substance = mole, time = second, length = meter, thermodynamic_temperature = kelvin, luminous_intensity = candela>, f32>

pub const FULL_TURN: Quantity<dyn Dimension<Kind = dyn AngleKind, N = Z0, J = Z0, M = Z0, L = Z0, I = Z0, T = Z0, Th = Z0>, dyn Units<f32, mass = kilogram, electric_current = ampere, amount_of_substance = mole, time = second, length = meter, thermodynamic_temperature = kelvin, luminous_intensity = candela>, f32>

pub const HALF_TURN: Quantity<dyn Dimension<Kind = dyn AngleKind, N = Z0, J = Z0, M = Z0, L = Z0, I = Z0, T = Z0, Th = Z0>, dyn Units<f64, mass = kilogram, electric_current = ampere, amount_of_substance = mole, time = second, length = meter, thermodynamic_temperature = kelvin, luminous_intensity = candela>, f64>

pub const FULL_TURN: Quantity<dyn Dimension<Kind = dyn AngleKind, N = Z0, J = Z0, M = Z0, L = Z0, I = Z0, T = Z0, Th = Z0>, dyn Units<f64, mass = kilogram, electric_current = ampere, amount_of_substance = mole, time = second, length = meter, thermodynamic_temperature = kelvin, luminous_intensity = candela>, f64>

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub const SPHERE: Quantity<dyn Dimension<Kind = dyn SolidAngleKind, N = Z0, J = Z0, M = Z0, L = Z0, I = Z0, T = Z0, Th = Z0>, dyn Units<f32, mass = kilogram, electric_current = ampere, amount_of_substance = mole, time = second, length = meter, thermodynamic_temperature = kelvin, luminous_intensity = candela>, f32>

pub const SPHERE: Quantity<dyn Dimension<Kind = dyn SolidAngleKind, N = Z0, J = Z0, M = Z0, L = Z0, I = Z0, T = Z0, Th = Z0>, dyn Units<f64, mass = kilogram, electric_current = ampere, amount_of_substance = mole, time = second, length = meter, thermodynamic_temperature = kelvin, luminous_intensity = candela>, f64>

pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.
pub fn get<N>(&self) -> V
where N: Unit + Conversion<V, T = <V as Conversion<V>>::T>,

Retrieve the value of the quantity in the given measurement unit.

Generic Parameters
  • N: Unit.