pub struct OverlappingStepsError<T: Debug + Ord> {
pub existing: Range<T>,
pub incoming: Range<T>,
}Expand description
Error returned when attempting to add a Step that overlaps an existing one.
This error can occur when creating a StepSchedule with overlapping steps,
or when pushing a new step into an existing schedule.
The existing field refers to a step already in the schedule,
and incoming is the step that overlaps it.
Fields
existing: Range<T>incoming: Range<T>Trait Implementations
Sourceimpl<T: Debug + Ord> Error for OverlappingStepsError<T>
impl<T: Debug + Ord> Error for OverlappingStepsError<T>
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()