ShellAndTubeConfigError

Enum ShellAndTubeConfigError 

pub enum ShellAndTubeConfigError {
    ZeroShellPasses,
    ShellPassOverflow,
    InsufficientTubePasses,
    TubePassesNotMultiple,
}
Errors returned when constructing a ShellAndTube arrangement.

Variants



ZeroShellPasses

No shell passes were configured.



ShellPassOverflow

The requested shell pass count is too large to validate.



InsufficientTubePasses

Tube passes are fewer than twice the shell passes.



TubePassesNotMultiple

Tube passes are not an even multiple of shell passes.