Struct CapacitanceRate
Source pub struct CapacitanceRate();
Capacitance rate (m_dot * c_p) of a working fluid in a heat exchanger.
The value must be strictly positive.
Create a CapacitanceRate from a scalar value.
Errors
Returns Err if the value is not strictly positive.
Create a CapacitanceRate from a quantity with thermal-conductance units.
Errors
Returns Err if the quantity is not strictly positive.
Create a CapacitanceRate from a mass rate and specific heat
capacity.
Errors
Returns Err if either operand is not strictly positive.
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
The resulting type after dereferencing.
Dereferences the value.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more
Tests less than (for
self and
other) and is used by the
< operator.
Read more
Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more
Tests greater than (for
self and
other) and is used by the
>
operator.
Read more
Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
🔬This is a nightly-only experimental API. (arbitrary_self_types)
The target type on which the method may be called.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.