Struct Effectiveness
Source pub struct Effectiveness();
The effectiveness of a heat exchanger.
The effectiveness is the ratio of the actual amount of heat transferred to
the maximum possible amount of heat transferred in the heat exchanger.
The effectiveness must be in the interval [0, 1].
Create an Effectiveness from a scalar value.
Errors
Returns Err if the value lies outside the interval [0, 1].
Create an Effectiveness from a ratio quantity.
Errors
Returns Err if the quantity lies outside the interval [0, 1].
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Retrieve the value of the quantity in the given measurement unit.
Generic Parameters
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
The resulting type after dereferencing.
Dereferences the value.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
🔬This is a nightly-only experimental API. (arbitrary_self_types)
The target type on which the method may be called.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.