#[non_exhaustive]pub enum CompressionError<Fluid> {
OutletPressureLessThanInlet {
p_in: Pressure,
p_out: Pressure,
},
NonPhysicalWork {
outlet: State<Fluid>,
raw_work: SpecificEnthalpy,
},
ThermodynamicModelFailed {
context: String,
source: Box<dyn StdError + Send + Sync>,
},
}Expand description
Errors that may occur when calling a compressor model.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OutletPressureLessThanInlet
The requested outlet pressure is less than the inlet pressure.
NonPhysicalWork
The computed target work is negative.
This is uncommon and is usually caused by very small pressure ratios combined with thermodynamic model numerical effects.
Includes the outlet state returned by the thermodynamic model so callers can decide how to recover without recomputing it.
ThermodynamicModelFailed
A thermodynamic model operation failed.
This failure can be from property evaluation or state construction.